% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run_app.R
\name{run_app}
\alias{run_app}
\title{Run the spatialLIBD Shiny Application}
\usage{
run_app(
  sce = fetch_data(type = "sce"),
  sce_layer = fetch_data(type = "sce_layer"),
  modeling_results = fetch_data(type = "modeling_results"),
  sig_genes = sig_genes_extract_all(n = nrow(sce_layer), modeling_results =
    modeling_results, sce_layer = sce_layer),
  image_path = system.file("app", "www", "data", package = "spatialLIBD"),
  sce_discrete_vars = c("GraphBased", "Layer", "Maynard", "Martinowich",
    paste0("SNN_k50_k", 4:28), "SpatialDE_PCA", "SpatialDE_pool_PCA", "HVG_PCA",
    "pseudobulk_PCA", "markers_PCA", "SpatialDE_UMAP", "SpatialDE_pool_UMAP", "HVG_UMAP",
    "pseudobulk_UMAP", "markers_UMAP", "SpatialDE_PCA_spatial",
    "SpatialDE_pool_PCA_spatial", "HVG_PCA_spatial", "pseudobulk_PCA_spatial",
    "markers_PCA_spatial", "SpatialDE_UMAP_spatial", "SpatialDE_pool_UMAP_spatial",
    "HVG_UMAP_spatial", "pseudobulk_UMAP_spatial", "markers_UMAP_spatial"),
  sce_continuous_vars = c("cell_count", "sum_umi", "sum_gene", "expr_chrM",
    "expr_chrM_ratio"),
  spatial_libd_var = "layer_guess_reordered_short",
  ...
)
}
\arguments{
\item{sce}{Defaults to the output of
\code{fetch_data(type = 'sce')}. This is a
\linkS4class{SingleCellExperiment}
object with the spot-level Visium data and information required for
visualizing the histology. See \code{\link[=fetch_data]{fetch_data()}} for more details.}

\item{sce_layer}{Defaults to the output of
\code{fetch_data(type = 'sce_layer')}. This is a
\linkS4class{SingleCellExperiment}
object with the spot-level Visium data compressed via pseudo-bulking to the
layer-level (group-level) resolution. See \code{\link[=fetch_data]{fetch_data()}} for more details.}

\item{modeling_results}{Defaults to the output of
\code{fetch_data(type = 'modeling_results')}. This is a list of tables with the
columns \verb{f_stat_*} or \verb{t_stat_*} as well as \verb{p_value_*} and \verb{fdr_*} plus
\code{ensembl}. The column name is used to extract the statistic results, the
p-values, and the FDR adjusted p-values. Then the \code{ensembl} column is used
for matching in some cases. See \code{\link[=fetch_data]{fetch_data()}} for more details.}

\item{sig_genes}{The output of \code{\link[=sig_genes_extract_all]{sig_genes_extract_all()}} which is a table
in long format with the modeling results.}

\item{image_path}{A path to the directory containing the low resolution
histology images that is needed for the interactive visualizations with
\code{plotly}. See
https://github.com/LieberInstitute/spatialLIBD/tree/master/inst/app/www/data
for an example of how these files should be organized.}

\item{sce_discrete_vars}{A \code{character()} vector of discrete variables that
will be available to visualize in the app. Basically, the set of variables
with spot-level groups. They will have to be present in \code{colData(sce)}.}

\item{sce_continuous_vars}{A \code{character()} vector of continuous variables
that will be available to visualize in the app using the same scale
as genes. They will have to be present in \code{colData(sce)}.}

\item{spatial_libd_var}{A \code{character(1)} with the name of the main cluster
variable to use. It will have to be present in both \code{colData(sce)} and
\code{colData(sce_layer)}.}

\item{...}{Other arguments passed to the list of golem options for running
the application.}
}
\value{
A \link[shiny:shiny.appobj]{shiny.appobj} that contains the input data.
}
\description{
This function runs the shiny application that allows users to interact
with the Visium spatial transcriptomics data from LIBD (by default) or
any other data that you have shaped according to our object structure.
}
\examples{

\dontrun{
## The default arguments will download the data from the web
## using fetch_data(). If this is the first time you have run this,
## the files will need to be cached by ExperimentHub. Otherwise it
## will re-use the files you have previously downloaded.
if (enough_ram(4e9)) {
    run_app()
}
}

}
