% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sce_image_gene.R
\name{sce_image_gene}
\alias{sce_image_gene}
\title{Sample spatial gene visualization}
\usage{
sce_image_gene(
  sce,
  sampleid,
  geneid = "SCGB2A2; ENSG00000110484",
  spatial = TRUE,
  assayname = "logcounts",
  minCount = 0,
  viridis = TRUE,
  ...
)
}
\arguments{
\item{sce}{Defaults to the output of
\code{fetch_data(type = 'sce')}. This is a
\linkS4class{SingleCellExperiment}
object with the spot-level Visium data and information required for
visualizing the histology. See \code{\link[=fetch_data]{fetch_data()}} for more details.}

\item{sampleid}{A \code{character(1)} specifying which sample to plot from
\code{colData(sce)$sample_name}.}

\item{geneid}{A \code{character(1)} specifying the gene ID stored in
\code{rowData(sce)$gene_search} or a continuous variable stored in \code{colData(sce)}
to visualize.}

\item{spatial}{A \code{logical(1)} indicating whether to include the histology
layer from \code{\link[=geom_spatial]{geom_spatial()}}. If you plan to use
\link[plotly:ggplotly]{ggplotly()} then it's best to set this to \code{FALSE}.}

\item{assayname}{The name of the \code{assays(sce)} to use for extracting the
gene expression data. Defaults to \code{logcounts}.}

\item{minCount}{A \code{numeric(1)} specifying the minimum gene expression (or
value in the continuous variable) to visualize. Values at or below this
threshold will be set to \code{NA}. Defaults to \code{0}.}

\item{viridis}{A \code{logical(1)} whether to use the color-blind friendly
palette from \link[viridisLite:viridis]{viridis} or the color palette used
in the paper that was chosen for contrast when visualizing the data on
top of the histology image. One issue is being able to differentiate low
values from NA ones due to the purple-ish histology information that is
dependent on cell density.}

\item{...}{Passed to \link[base:paste]{paste0()} for making the title of the
plot following the \code{sampleid}.}
}
\value{
A \link[ggplot2:ggplot]{ggplot2} object.
}
\description{
This function visualizes the gene expression stored in \code{assays(sce)} or any
continuous variable stored in \code{colData(sce)} for one given sample at the
spot-level using (by default) the histology information on the background.
To visualize clusters (or any discrete variable) use \code{\link[=sce_image_clus]{sce_image_clus()}}.
}
\details{
This function subsets \code{sce} to the given sample and prepares the
data and title for \code{\link[=sce_image_gene_p]{sce_image_gene_p()}}. It also adds a caption to the plot.
}
\examples{

if (enough_ram()) {
    ## Obtain the necessary data
    if (!exists("sce")) sce <- fetch_data("sce")

    ## Valid `geneid` values are those in
    head(rowData(sce)$gene_search)
    ## or continuous variables stored in colData(sce)

    ## Visualize a default gene on the non-viridis scale
    sce_image_gene(
        sce = sce,
        sampleid = "151507",
        viridis = FALSE
    )

    ## Visualize a continuous variable, in this case, the ratio of chrM
    ## gene expression compared to the total expression at the spot-level
    sce_image_gene(
        sce = sce,
        sampleid = "151507",
        geneid = "expr_chrM_ratio"
    )
}
}
\seealso{
Other Spatial gene visualization functions: 
\code{\link{sce_image_gene_p}()},
\code{\link{sce_image_grid_gene}()}
}
\concept{Spatial gene visualization functions}
