% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sce_image_gene_p.R
\name{sce_image_gene_p}
\alias{sce_image_gene_p}
\title{Sample spatial gene visualization workhorse function}
\usage{
sce_image_gene_p(sce, d, sampleid, spatial, title, viridis = TRUE)
}
\arguments{
\item{sce}{Defaults to the output of
\code{fetch_data(type = 'sce')}. This is a
\linkS4class{SingleCellExperiment}
object with the spot-level Visium data and information required for
visualizing the histology. See \code{\link[=fetch_data]{fetch_data()}} for more details.}

\item{d}{A data.frame with the sample-level information. This is typically
obtained using \code{as.data.frame(colData(sce))}. The data.frame has to contain
a column with the continuous variable data to plot stored under \code{d$COUNT}.}

\item{sampleid}{A \code{character(1)} specifying which sample to plot from
\code{colData(sce)$sample_name}.}

\item{spatial}{A \code{logical(1)} indicating whether to include the histology
layer from \code{\link[=geom_spatial]{geom_spatial()}}. If you plan to use
\link[plotly:ggplotly]{ggplotly()} then it's best to set this to \code{FALSE}.}

\item{title}{The title for the plot.}

\item{viridis}{A \code{logical(1)} whether to use the color-blind friendly
palette from \link[viridisLite:viridis]{viridis} or the color palette used
in the paper that was chosen for contrast when visualizing the data on
top of the histology image. One issue is being able to differentiate low
values from NA ones due to the purple-ish histology information that is
dependent on cell density.}
}
\value{
A \link[ggplot2:ggplot]{ggplot2} object.
}
\description{
This function visualizes the gene expression stored in \code{assays(sce)} or any
continuous variable stored in \code{colData(sce)} for one given sample at the
spot-level using (by default) the histology information on the background.
This is the function that does all the plotting behind \code{\link[=sce_image_gene]{sce_image_gene()}}.
To visualize clusters (or any discrete variable) use \code{\link[=sce_image_clus_p]{sce_image_clus_p()}}.
}
\examples{

if (enough_ram()) {
    ## Obtain the necessary data
    if (!exists("sce")) sce <- fetch_data("sce")

    ## Prepare the data for the plotting function
    sce_sub <- sce[, sce$sample_name == "151673"]
    df <- as.data.frame(colData(sce_sub))
    df$COUNT <- df$expr_chrM_ratio

    ## Use the manual color palette by Lukas M Weber
    ## Don't plot the histology information
    sce_image_gene_p(
        sce = sce_sub,
        d = df,
        sampleid = "151673",
        title = "151673 chrM expr ratio",
        spatial = FALSE
    )

    ## Clean up
    rm(sce_sub)
}
}
\seealso{
Other Spatial gene visualization functions: 
\code{\link{sce_image_gene}()},
\code{\link{sce_image_grid_gene}()}
}
\concept{Spatial gene visualization functions}
